@@ -2,12 +2,12 @@ mod brush_plane;
 
 pub use brush_plane::*;
 
-use std::{fmt::Display, ops::Deref};
+use std::{fmt::Display, ops::{Deref, DerefMut}};
 
 /// The convex volume represented by a set of [`BrushPlane`]s.
 #[derive(Debug, Default, Clone, PartialEq, PartialOrd)]
 #[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
-pub struct Brush(Vec<BrushPlane>);
+pub struct Brush(pub Vec<BrushPlane>);
 
 impl Brush {
     pub fn new(entities: Vec<BrushPlane>) -> Self {
@@ -29,6 +29,12 @@ impl Deref for Brush {
     }
 }
 
+impl DerefMut for Brush {
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+
 impl Display for Brush {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         writeln!(f, "{{")?;
