@@ -2,14 +2,14 @@ mod brush;
 
 pub use brush::*;
 
-use std::{fmt::Display, ops::Deref};
+use std::{fmt::Display, ops::{Deref, DerefMut}};
 
 #[cfg(doc)]
 use crate::repr::Entity;
 /// The set of brushes inside an [`Entity`].
 #[derive(Debug, Default, Clone, PartialEq, PartialOrd)]
 #[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
-pub struct Brushes(Vec<Brush>);
+pub struct Brushes(pub Vec<Brush>);
 
 impl Brushes {
     pub fn new(brushes: Vec<Brush>) -> Self {
@@ -31,6 +31,12 @@ impl Deref for Brushes {
     }
 }
 
+impl DerefMut for Brushes {
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+
 impl Display for Brushes {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         for i in 0..self.len().checked_sub(1).unwrap_or_default() {
